/*
 * @Author: PoJun
 * @Date: 2023-09-08 11:53:43
 * @LastEditors: PoJun
 * @LastEditTime: 2023-12-20 11:33:29
 * @Message: 枚举、字典的前端管理, 做缓存机制
 */
import { getEnumInfo, getDictItemsByCode, getDictList } from "@/api/index.js";
import store from "@/store";

// 出于美观问题. 简化一下, 不然调用的时候太难看了
const NUEMS = {
    SecurityAuthTypeEnum: "com.kingtom.kirin.app.auth.AuthConst$SecurityAuthTypeEnum", //账号类型
    AuthcEncodeEnum: "com.kingtom.kirin.app.auth.AuthConst$AuthcEncodeEnum", // 编码类型, 加密方式
    AuthcRealmTypeEnum: "com.kingtom.kirin.app.auth.AuthConst$AuthcRealmTypeEnum", // 登录方式
    AuthMenuTypeEnum: "com.kingtom.kirin.app.auth.AuthConst$AuthMenuTypeEnum", // 菜单目录的类型.
    AuthMenuActionTypeEnum: "com.kingtom.kirin.app.auth.AuthConst$AuthMenuActionTypeEnum", //菜单类型
    BooleanEnum: "com.kingtom.kirin.core.common.CommonConst$BooleanEnum", // 布尔类型
    DdicInfoShowModelEnum: "com.kingtom.kirin.app.ddic.DdicConst$DdicInfoShowModelEnum", //字典展示模式
    ConfInfoValueTypeEnum: "com.kingtom.kirin.app.conf.ConfConst$ConfInfoValueTypeEnum", //环境配置类型
    OrgUnitIndustryEnum: "com.kingtom.kirin.app.org.OrgConst$OrgUnitIndustryEnum", //企业所属行业
    OrgUnitTypeEnum: "com.kingtom.kirin.app.org.OrgConst$OrgUnitTypeEnum", //企业类型
};
// 枚举数据获取, 为避免枚举和字典的code冲突(当然一般不会), 所以分开存储
export const getEnumByClass = enumClassName => {
    const enumsData = store.state.setting.enumsData;

    if (enumsData[enumClassName]) {
        return Promise.resolve(enumsData[enumClassName]);
    } else {
        return getEnumInfo(NUEMS[enumClassName]).then(res => {
            return (enumsData[enumClassName] = res);
        });
    }
};

// 字典数据获取
export const getDictByCode = code => {
    const dictData = store.state.setting.dictData;

    if (dictData[code]) {
        return Promise.resolve(dictData[code]);
    } else {
        return getDictItemsByCode(code).then(res => {
            return (dictData[code] = res);
        });
    }
};

// 页面初始化需要的字典数据, 获取后存入vuex页面调用
export const initDictList = async ids => {
    const dictData = store.state.setting.dictData;
    const ar = ids.split(",");
    const nAr = ar.filter(item => !dictData[item]);
    if (nAr.length != 0) {
        const data = await getDictList({ codes: ids });
        for (const key in data) {
            if (Object.hasOwnProperty.call(data, key)) {
                dictData[key] = data[key];
            }
        }
    }
};
