/*
 * @Author: PoJun
 * @Date: 2023-08-18 14:01:44
 * @LastEditors: PoJun
 * @LastEditTime: 2024-01-18 15:00:59
 * @Message: 组件注册, 但是由于大部分是动态的, 所以只注册静态组件
 */
// 视图组件
const view = {
    tabs: () => import("@/layouts/tabs"),
    blank: () => import("@/layouts/BlankView"),
};

// 路由组件注册
const routerMap = {
    login: {
        authority: "*",
        path: "/login",
        name: "登录",
        component: () => import("@/pages/login/login"),
    },
    exp403: {
        name: "exp403",
        path: "403",
        component: () => import("@/pages/exception/403"),
    },
    exp404: {
        name: "exp404",
        path: "404",
        component: () => import("@/pages/exception/404"),
    },
    exp500: {
        name: "exp500",
        path: "500",
        component: () => import("@/pages/exception/500"),
    },
    root: {
        path: "/",
        component: view.tabs,
        redirect: "/login",
    },
    home: {
        name: "首页",
        path: "/home",
        component: () => import("@/pages/home/home"),
    },
    account: {
        name: "个人设置",
        path: "/account",
        component: () => import("@/pages/account/account"),
    },
    permission: {
        name: "权限设置",
        component: view.blank,
    },
    permission_user: {
        name: "用户管理",
        component: () => import("@/pages/permission/user"),
    },
    permission_role: {
        name: "角色管理",
        component: () => import("@/pages/permission/role"),
    },
    permission_menu: {
        name: "菜单管理",
        component: () => import("@/pages/permission/menu"),
    },
    system: {
        name: "系统配置",
        component: view.blank,
    },
    system_info: {
        name: "系统信息",
        component: () => import("@/pages/system/info"),
    },
    system_dict: {
        name: "数据字典",
        component: () => import("@/pages/system/dict"),
    },
    system_dictData: {
        name: "字典详情",
        component: () => import("@/pages/system/dictData"),
    },
    system_env: {
        name: "环境配置",
        component: () => import("@/pages/system/env"),
    },
    organization: {
        name: "组织管理",
        component: view.blank,
    },
    organization_info: {
        name: "组织信息",
        component: () => import("@/pages/organization/info"),
    },
    organization_personnel: {
        name: "人员管理",
        component: () => import("@/pages/organization/personnel"),
    },
    organization_dep: {
        name: "部门管理",
        component: () => import("@/pages/organization/dep"),
    },
    organization_post: {
        name: "岗位管理",
        component: () => import("@/pages/organization/post"),
    },
    srm: {
        name: "SRM管理",
        component: view.blank,
    },
    srm_products: {
        name: "产品目录",
        component: () => import("@/pages/srm/products"),
    },
    srm_supplier: {
        name: "供应商管理",
        component: () => import("@/pages/srm/supplier"),
    },
    affairs: {
        name: "事务中心",
        component: view.blank,
    },
    affairs_transaction: {
        name: "事务处理",
        component: () => import("@/pages/affairs/transaction"),
    },
    process: {
        name: "流程中心",
        component: view.blank,
    },
    process_definition: {
        name: "流程定义",
        component: () => import("@/pages/process/definition"),
    },
    process_instance: {
        name: "流程实例",
        component: () => import("@/pages/process/instance"),
    },
    test: {
        component: view.blank,
    },
    empty: {
        component: () => import("@/pages/home/empty"),
    },
};
export default routerMap;
